==> ugene_1.25.0+dfsg.orig.tar.xz: ugene-1.25.0/src/corelibs/U2View/src/ov_msa/ExportHighlightedDialogController.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_EXPORT_HIGHLIGHTING_DIALOG_CONTROLLER_H_
#define _U2_EXPORT_HIGHLIGHTING_DIALOG_CONTROLLER_H_

#include <QDialog>

#include "MSAEditor.h"

class Ui_ExportHighlightedDialog;

namespace U2 {

class SaveDocumentController;

class ExportHighligtingDialogController : public QDialog{
    Q_OBJECT
public:
    ExportHighligtingDialogController(MSAEditorUI *msaui_, QWidget* p);
    ~ExportHighligtingDialogController();

    virtual void accept();
    void lockKeepGaps();

    int startPos;
    int endPos;
    int startingIndex;
    bool keepGaps;
    bool dots;
    bool transpose;
    GUrl url;

private slots:
    void endPosValueChanged();

private:
    void initSaveController();

    MSAEditorUI *msaui;
    SaveDocumentController *saveController;
    Ui_ExportHighlightedDialog* ui;
};

}

#endif

==> ugene_1.31.1.1+dfsg+rb2.orig.tar.xz: ugene-1.31.1.1+dfsg+rb2/src/corelibs/U2View/src/ov_msa/ExportHighlightedDialogController.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2018 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_EXPORT_HIGHLIGHTING_DIALOG_CONTROLLER_H_
#define _U2_EXPORT_HIGHLIGHTING_DIALOG_CONTROLLER_H_

#include <QDialog>

#include "MSAEditor.h"

class Ui_ExportHighlightedDialog;

namespace U2 {

class SaveDocumentController;

class ExportHighligtingDialogController : public QDialog{
    Q_OBJECT
public:
    ExportHighligtingDialogController(MaEditorWgt *msaui_, QWidget* p);
    ~ExportHighligtingDialogController();

    virtual void accept();
    void lockKeepGaps();

    int startPos;
    int endPos;
    int startingIndex;
    bool keepGaps;
    bool dots;
    bool transpose;
    GUrl url;

private slots:
    void sl_regionChanged();

private:
    void initSaveController();

    MaEditorWgt *msaui;
    SaveDocumentController *saveController;
    Ui_ExportHighlightedDialog* ui;
};

}

#endif
